@@ -6,7 +6,7 @@
 API_URL_MAPPING = {
     'terminal-register': '/api/terminal/v1/terminal/',
     'terminal-access-key': '/api/terminal/v1/terminal/%s/access-key',
-    'terminal-heartbeat': '/api/terminal/v1/terminal/status/',
+    'terminal-heartbeat': '/api/v1/terminal/terminals/status/',
     'session-replay': '/api/terminal/v1/sessions/%s/replay/',
     'session-list': '/api/terminal/v1/sessions/',
     'session-detail': '/api/terminal/v1/sessions/%s/',
